package xyz.brysonsteck.ServerCraft.dialogs

import javafx.scene.control.Button
import javafx.scene.control.Label
import javafx.scene.control.ButtonBar
import javafx.scene.image.Image
import javafx.scene.image.ImageView
import javafx.scene.layout.Pane
import javafx.scene.Scene
import javafx.stage.Stage
import javafx.stage.Modality
import javafx.geometry.Insets
import javafx.event.EventHandler
import javafx.event.ActionEvent
import xyz.brysonsteck.ServerCraft.App

open class Dialog {
  private var result = false

  private val type: String
  private val title: String
  private val msg: String
  private val yes: String
  private val no: String
  private val neutral: Button?
  private val hold: Boolean

  constructor(type: String, 
              title: String,
              msg: String, 
              yes: String = "Yes",
              no: String = "No", 
              neutral: Button?, 
              hold: Boolean = true) {
    this.type = type
    this.title = title
    this.msg = msg
    this.yes = yes
    this.no = no
    this.neutral = neutral
    this.hold = hold
  }

  public fun show(): Boolean {
    val resources = App().javaClass.getResource("icons/$type.png")
    val dialog = Stage()
    dialog.icons.add(Image(App().javaClass.getResourceAsStream("app.png")))
    dialog.setResizable(false)
    dialog.initModality(Modality.APPLICATION_MODAL);
    dialog.title = title
    val scenePane = Pane()
    val dialogScene = Scene(scenePane, 400.0, 150.0);
    val imagePane = Pane()
    val icon = Image("$resources")
    imagePane.layoutX = 14.0
    imagePane.layoutY = 14.0
    imagePane.scaleX = 0.7
    imagePane.scaleY = 0.7
    imagePane.children.add(ImageView(icon))
    val label = Label(msg)
    label.isWrapText = true
    label.layoutX = 115.0
    label.layoutY = if (type == "warning") {10.0} else {40.0}
    val buttonBar = ButtonBar()
    buttonBar.padding = Insets(10.0, 10.0, 10.0, 10.0)
    buttonBar.layoutX = 0.0
    buttonBar.layoutY = 107.0
    buttonBar.prefWidth = 400.0
    val noButton = Button(no)
    noButton.onAction = EventHandler<ActionEvent>() {
      result = false
      dialog.hide()
    }
    val yesButton = Button(yes)
    yesButton.onAction = EventHandler<ActionEvent>() {
      result = true
      dialog.hide()
    }
    yesButton.isDefaultButton = true
    buttonBar.buttons.add(noButton)
    buttonBar.buttons.add(yesButton)
    scenePane.children.addAll(imagePane, label, buttonBar)
    ButtonBar.setButtonData(noButton, ButtonBar.ButtonData.RIGHT)
    ButtonBar.setButtonData(yesButton, ButtonBar.ButtonData.RIGHT)
    buttonBar.buttons.add(noButton)
    buttonBar.buttons.add(yesButton)
    dialog.setScene(dialogScene);
    if (hold) {
      dialog.showAndWait();
    } else {
      dialog.show();
    }
    return result
  }

}